CyGL
====

CyGL is a companion package to TkGL.  It provides a Cython-based OpenGL client
which can be used to make a working application with a TkGL rendering surface.

This project is currently only a skeleton.  This README will be expanded once
the project is functional.
